==> huaweicloudsdkbcs-3.0.46-py2.py3-none-any.whl: huaweicloudsdkbcs/v2/model/batch_add_peers_to_channel_request.py <==
# coding: utf-8

import pprint
import re

import six





class BatchAddPeersToChannelRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'blockchain_id': 'str',
        'body': 'BatchAddPeersToChannelRequestBody'
    }

    attribute_map = {
        'blockchain_id': 'blockchain_id',
        'body': 'body'
    }

    def __init__(self, blockchain_id=None, body=None):
        """BatchAddPeersToChannelRequest - a model defined in huaweicloud sdk"""
        
        

        self._blockchain_id = None
        self._body = None
        self.discriminator = None

        self.blockchain_id = blockchain_id
        if body is not None:
            self.body = body

    @property
    def blockchain_id(self):
        """Gets the blockchain_id of this BatchAddPeersToChannelRequest.

        bcs 服务id

        :return: The blockchain_id of this BatchAddPeersToChannelRequest.
        :rtype: str
        """
        return self._blockchain_id

    @blockchain_id.setter
    def blockchain_id(self, blockchain_id):
        """Sets the blockchain_id of this BatchAddPeersToChannelRequest.

        bcs 服务id

        :param blockchain_id: The blockchain_id of this BatchAddPeersToChannelRequest.
        :type: str
        """
        self._blockchain_id = blockchain_id

    @property
    def body(self):
        """Gets the body of this BatchAddPeersToChannelRequest.


        :return: The body of this BatchAddPeersToChannelRequest.
        :rtype: BatchAddPeersToChannelRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchAddPeersToChannelRequest.


        :param body: The body of this BatchAddPeersToChannelRequest.
        :type: BatchAddPeersToChannelRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchAddPeersToChannelRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbcs-3.0.52-py2.py3-none-any.whl: huaweicloudsdkbcs/v2/model/batch_add_peers_to_channel_request.py <==
# coding: utf-8

import re
import six





class BatchAddPeersToChannelRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'blockchain_id': 'str',
        'body': 'BatchAddPeersToChannelRequestBody'
    }

    attribute_map = {
        'blockchain_id': 'blockchain_id',
        'body': 'body'
    }

    def __init__(self, blockchain_id=None, body=None):
        """BatchAddPeersToChannelRequest - a model defined in huaweicloud sdk"""
        
        

        self._blockchain_id = None
        self._body = None
        self.discriminator = None

        self.blockchain_id = blockchain_id
        if body is not None:
            self.body = body

    @property
    def blockchain_id(self):
        """Gets the blockchain_id of this BatchAddPeersToChannelRequest.

        bcs 服务id

        :return: The blockchain_id of this BatchAddPeersToChannelRequest.
        :rtype: str
        """
        return self._blockchain_id

    @blockchain_id.setter
    def blockchain_id(self, blockchain_id):
        """Sets the blockchain_id of this BatchAddPeersToChannelRequest.

        bcs 服务id

        :param blockchain_id: The blockchain_id of this BatchAddPeersToChannelRequest.
        :type: str
        """
        self._blockchain_id = blockchain_id

    @property
    def body(self):
        """Gets the body of this BatchAddPeersToChannelRequest.


        :return: The body of this BatchAddPeersToChannelRequest.
        :rtype: BatchAddPeersToChannelRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this BatchAddPeersToChannelRequest.


        :param body: The body of this BatchAddPeersToChannelRequest.
        :type: BatchAddPeersToChannelRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchAddPeersToChannelRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
